#
# spec file for package python-repoze.who
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global modname repoze.who
%{?sle15_python_module_pythons}
%global skip_python313 1
Name:           python-repoze.who
Version:        3.0.0
Release:        2.2
Summary:        Identification and authentication framework for WSGI
License:        SUSE-Repoze
URL:            http://www.repoze.org
Source:         https://files.pythonhosted.org/packages/source/r/repoze.who/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module WebOb}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module zope.interface}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-WebOb
Requires:       python-zope.interface
BuildArch:      noarch
%python_subpackages

%description
repoze.who is an identification and authentication framework
for arbitrary WSGI applications.  repoze.who can be configured
either as WSGI middleware or as an API for use by an application.

repoze.who is inspired by Zope 2's Pluggable Authentication
Service (PAS) (but repoze.who is not dependent on Zope in any
way; it is useful for any WSGI application).  It provides no facility
for authorization (ensuring whether a user can or cannot perform the
operation implied by the request).  This is considered to be the
domain of the WSGI application.

%prep
%setup -q -n %{modname}-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}/

%check
%pytest

%files %{python_files}
%license LICENSE.txt
%doc *.txt
%{python_sitelib}/*

%changelog
* Tue Oct 29 2024 Dirk Müller <dmueller@suse.com>
- skip build on 3.13
* Fri Dec  8 2023 Dirk Müller <dmueller@suse.com>
- update to 3.0.0:
  * Add support for Python 3.9, 3.10 and 3.11.
  * Drop support for Python 2.7, 3.4, 3.5, and 3.6.
  * Add Github Actions workflow to exercise unit tests /
    coverage.
* Sun Jun 11 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Sat Dec  3 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v2.4.1
  * Disallow separators in AuthTicket component values. Closes #37.
  * Handle bytes / string correctly in ‘repoze.who.plugins.htpasswd.sha1_check’. Closes #28.
  * Switch to use pytest as the testrunner. Closes #34.
* Mon Aug  3 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 2.4
  * Add support for Python 3.6, 3.7, and 3.8.
  * Drop support for Python 3.3.
  * Fix travis configuration.
  * Add ``samesite`` option to AuthTktCookiePlugin constructor.
    If this is passed, it should be a string, and it will be used
    to compose the Set-Cookie header's "SameSite" value, e.g.
    if you pass ``samesite="Strict"`` into the constructor,
    the cookie value for the auth tkt cooke will contain
    ``SameSite=Strict``.
* Mon Apr  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Skip failing test as it the zope.interface now raises different
  assert
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Feb  9 2018 tbechtold@suse.com
- Add missing BuildRequires for doc build
* Mon Jul 10 2017 okurz@suse.com
- Convert to singlespec
* Tue Oct  6 2015 dmueller@suse.com
- fix license (SUSE-Repoze)
- update to 2.2:
  Parse INI-file configuration using ``SafeConfigParser``:  allows
  escaping the ``'%%'`` so that e.g. a query template using for a DB-API
  connection using ``pyformat`` preserves the template.
  Added support for Python 3.3, PyPy.
  - ``_compat`` module:  tolerate missing ``CONTENT_TYPE`` key in the WSGI
    environment.  Thanks to Dag Hoidal for the patch.
  - ``htpasswd`` plugin:  add a ``sha1_check`` checker function (the ``crypt``
    module is not available on Windows).  Thanks to Chandrashekar Jayaraman
    for the patch.
  - Documentation typo fixes from Carlos de la Guardia and Atsushi Odagiri.
* Wed Feb  1 2012 saschpe@suse.de
- Initial version
